# coding: utf-8
# /*##########################################################################
#
# Copyright (c) 2015-2016 European Synchrotron Radiation Facility
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#
# ###########################################################################*/

from __future__ import absolute_import

__authors__ = ["D. Naudet"]
__license__ = "MIT"
__date__ = "01/11/2016"


import logging

from .Hdf5Nodes import H5Base, H5NodeFactory
from .ProjectItem import ProjectItem


_logger = logging.getLogger(__name__)


def h5NodeToProjectItem(h5Node, mode='r', cast=True):
    if not isinstance(h5Node, H5Base):
        return None
    try:
        item = ProjectItem(h5Node.h5File, nodePath=h5Node.h5Path, mode=mode)
    except Exception as ex:
        _logger.error(ex)
        raise

    if cast:
        item = item.cast()
    return item


def XsocsH5Factory(h5File, h5Path):
    node = H5NodeFactory(h5File, h5Path)
    if node.isValid():
        item = h5NodeToProjectItem(node, cast=False)
        if item and item.isHidden():
            node.hidden = True
    return node
